# $Id: install.py 1227 2015-01-25 13:12:27Z mwall $
# installer for ThinkSpeak
# Copyright 2014 Matthew Wall

from setup import ExtensionInstaller

def loader():
    return ThingSpeakInstaller()

class ThingSpeakInstaller(ExtensionInstaller):
    def __init__(self):
        super(ThingSpeakInstaller, self).__init__(
            version="0.2",
            name='thingspeak',
            description='Upload weather data to ThingSpeak.',
            author="Matthew Wall",
            author_email="mwall@users.sourceforge.net",
            restful_services='user.thingspeak.ThingSpeak',
            config={
                'StdRESTful': {
                    'ThingSpeak': {
                        'token': 'INSERT_TOKEN_HERE'}}},
            files=[('bin/user', ['bin/user/thingspeak.py'])]
            )
